@@ -18,11 +18,11 @@ class DataCuration:
     __key_2 = None
     __key_3 = None
     __grouping = None
-    tables = dict()
-    formed_tables = dict()
-    list_files = list()
+    tables = None
+    formed_tables = None
+    list_files = None
     __key_separator = " -:- "
-    __link_headers = dict()
+    __link_headers = None
 
     def __init__(self, grouping, key_1, key_2=None, key_3=None):
         """
@@ -49,6 +49,10 @@ class DataCuration:
         )
         df_issues["step_number"] = df_issues["step_number"].astype(int)
         self.df_issues = df_issues
+        self.tables = dict()
+        self.formed_tables = dict()
+        self.list_files = list()
+        self.__link_headers = dict()
         module_logger.info("Initialising `DataCuration` object complete")
 
     def error_handling(self, file, subfile, issue_short_desc, issue_long_desc,
@@ -484,17 +488,20 @@ class DataCuration:
 
     @staticmethod
     def __assert_linked_headers(
-        list_ideal_headers, dict_header, df, reset_index):
+        list_ideal_headers, dict_header, df, remove_header_rows, reset_index):
         list_expected_headers = dict_header['expected_headers']
         list_new_names = dict_header['new_headers']
         list_remove = [
-            item for item in dict_header['remove'] if not pd.isnull(item)]
+            dict_header['new_headers'][i] for i in range(len(dict_header['remove'])) 
+            if dict_header['remove'][i] == 'remove'
+        ]
 
         # Remove the expected headers rows
-        df.drop(
-            [i for i in range(len(list_expected_headers))],
-            axis=0,
-            inplace=True)
+        if remove_header_rows:
+            df.drop(
+                [i for i in range(len(list_expected_headers))],
+                axis=0,
+                inplace=True)
         if reset_index:
             df.reset_index(drop=True, inplace=True)
 
@@ -507,8 +514,8 @@ class DataCuration:
 
         # Fill in missing columns and reorder columns
         list_df_cols = df.columns.tolist()
-        list_cols = [col for col in list_ideal_headers if
-                    col not in list_df_cols]
+        list_cols = [
+            col for col in list_ideal_headers if col not in list_df_cols]
         for col in list_cols:
             df[col] = np.nan
 
@@ -516,7 +523,8 @@ class DataCuration:
 
         return df
 
-    def assert_linked_headers(self, reset_index=True):
+    def assert_linked_headers(
+            self, remove_header_rows=False, reset_index=False):
         module_logger.info("Starting `assert_linked_headers`")
 
         if type(self.tables).__name__ == 'dict':
@@ -526,6 +534,7 @@ class DataCuration:
                     self.headers['ideal_headers'],
                     self.headers[self.__link_headers[key]],
                     dict_dfs[key],
+                    remove_header_rows,
                     reset_index
                 )
             self.set_table(dict(dict_dfs))
@@ -535,6 +544,7 @@ class DataCuration:
                 self.headers['ideal_headers'],
                 self.headers[self.__link_headers[key]],
                 self.tables,
+                remove_header_rows,
                 reset_index
             )
             self.set_table(df.copy())
@@ -814,7 +824,10 @@ class DataCuration:
     def __convert_col(self, df, dict_convert, dict_key, **kwargs):
         module_logger.info("Starting `__convert_col`")
         for convert_key in dict_convert.keys():
-            list_cols = dict_convert[convert_key]["columns"]
+            cols = dict_convert[convert_key]["columns"]
+            if type(cols).__name__ == 'function':
+                cols = cols(df, **kwargs)
+            list_cols = list(cols)
             list_stops = dict_convert[convert_key]["dtypes"]
             dict_functions = dict_convert[convert_key]["functions"]
             for col in list_cols:
